@@ -6,14 +6,15 @@ import sys
 from collections import defaultdict
 from contextlib import AbstractContextManager
 from contextvars import ContextVar
-from typing import TYPE_CHECKING, Any, Union, Sequence, Optional, Iterator, Collection, cast, Dict, Tuple, List
+from typing import TYPE_CHECKING, Any, Union, Sequence, Optional, Iterator, Collection, Callable, cast
+from typing import Dict, Tuple, List
 
 try:
     from functools import cached_property
 except ImportError:
     from .compat import cached_property
 
-from .config import ShowDefaults
+from .config import ShowDefaults, CommandConfig
 from .error_handling import ErrorHandler, NullErrorHandler, extended_error_handler
 from .exceptions import NoActiveContext
 from .utils import Bool, _NotSet
@@ -21,6 +22,7 @@ from .utils import Bool, _NotSet
 if TYPE_CHECKING:
     from .core import CommandType
     from .command_parameters import CommandParameters
+    from .formatting.params import ParamHelpFormatter
     from .parameters import Parameter, ParamOrGroup, ActionFlag
 
 __all__ = ['Context', 'ctx', 'get_current_context']
@@ -57,7 +59,9 @@ class ConfigOption:
         try:
             config = command.__class__.config(command)
         except AttributeError:
-            return self.default
+            if self.default is not None:
+                return self.default
+            return getattr(CommandConfig(), self.name)
         else:
             return getattr(config, self.name)
 
@@ -83,6 +87,11 @@ class Context(AbstractContextManager):  # Extending AbstractContextManager to ma
     allow_backtrack = ConfigOption()
     use_type_metavar = ConfigOption()
     show_defaults = ConfigOption()
+    show_group_tree = ConfigOption()
+    show_group_type = ConfigOption()
+    param_formatter = ConfigOption()
+    extended_epilog = ConfigOption()
+    show_docstring = ConfigOption()
     # strict_option_punctuation = ConfigOption()
     # strict_action_punctuation = ConfigOption()
     # strict_sub_command_punctuation = ConfigOption()
@@ -102,6 +111,11 @@ class Context(AbstractContextManager):  # Extending AbstractContextManager to ma
         allow_backtrack: Bool = None,
         use_type_metavar: Bool = None,
         show_defaults: Union[ShowDefaults, str, int] = None,
+        show_group_tree: Bool = None,
+        show_group_type: Bool = None,
+        param_formatter: Callable[['ParamOrGroup'], 'ParamHelpFormatter'] = None,
+        extended_epilog: Bool = None,
+        show_docstring: Bool = None,
         # strict_option_punctuation: Bool = None,
         # strict_action_punctuation: Bool = None,
         # strict_sub_command_punctuation: Bool = None,
@@ -135,6 +149,11 @@ class Context(AbstractContextManager):  # Extending AbstractContextManager to ma
         self.use_type_metavar = use_type_metavar
         if show_defaults is not None:
             self.show_defaults = ShowDefaults(show_defaults)
+        self.show_group_tree = show_group_tree
+        self.show_group_type = show_group_type
+        self.param_formatter = param_formatter
+        self.extended_epilog = extended_epilog
+        self.show_docstring = show_docstring
 
         # self.strict_option_punctuation = strict_option_punctuation
         # self.strict_action_punctuation = strict_action_punctuation
