@@ -6,20 +6,22 @@ Parameter usage / help text formatters
 
 from itertools import chain
 from textwrap import indent
-from typing import Type
+from typing import Type, Tuple
 
 from ..context import ctx
 from ..exceptions import NoActiveContext
 from ..utils import Bool
 from ..parameters import ParamBase, ParamGroup, ParamOrGroup, ChoiceMap, PassThru, BasePositional, BaseOption
+from .restructured_text import RstTable
 from .utils import HelpEntryFormatter, _should_add_default
 
 
 class ParamHelpFormatter:
     _param_cls_fmt_cls_map = {}
 
-    def __init_subclass__(cls, param_cls: Type[ParamBase]):  # noqa
-        cls._param_cls_fmt_cls_map[param_cls] = cls
+    def __init_subclass__(cls, param_cls: Type[ParamBase] = None):  # noqa
+        if param_cls is not None:
+            cls._param_cls_fmt_cls_map[param_cls] = cls
 
     @classmethod
     def for_param_cls(cls, param_cls: Type['ParamBase']) -> Type['ParamHelpFormatter']:
@@ -70,12 +72,14 @@ class ParamHelpFormatter:
     def format_usage(self, include_meta: Bool = False, full: Bool = False, delim: str = ', ') -> str:
         return self.format_metavar()
 
-    def format_description(self) -> str:
+    def format_description(self, rst: Bool = False) -> str:
         param = self.param
         description = param.help or ''
-        if _should_add_default(param.default, param.help):
+        if _should_add_default(param.default, description, param.show_default):
             pad = ' ' if description else ''
-            description += f'{pad}(default: {param.default})'
+            quote = '``' if rst else ''
+            description += f'{pad}(default: {quote}{param.default!r}{quote})'
+
         return description
 
     def format_help(self, width: int = 30, prefix: str = '', tw_offset: int = 0) -> str:
@@ -85,6 +89,10 @@ class ParamHelpFormatter:
         text = HelpEntryFormatter(usage, description, entry_width, tw_offset=tw_offset)()
         return indent(text, prefix) if prefix else text
 
+    def rst_row(self) -> Tuple[str, str]:
+        usage = self.format_usage(include_meta=True, full=True)
+        return f'``{usage}``', self.format_description(rst=True)
+
 
 class PositionalHelpFormatter(ParamHelpFormatter, param_cls=BasePositional):
     def format_basic_usage(self) -> str:
@@ -128,7 +136,7 @@ class ChoiceMapHelpFormatter(PositionalHelpFormatter, param_cls=ChoiceMap):
         return self.format_metavar()
 
     def format_help(self, width: int = 30, prefix: str = '', tw_offset: int = 0) -> str:
-        param = self.param
+        param: ChoiceMap = self.param
         usage = self.format_usage()
         entry_width = max(20, width - tw_offset)
         help_entry = HelpEntryFormatter(usage, param.description, entry_width, lpad=2, tw_offset=tw_offset)()
@@ -141,6 +149,14 @@ class ChoiceMapHelpFormatter(PositionalHelpFormatter, param_cls=ChoiceMap):
         text = '\n'.join(parts)
         return indent(text, prefix) if prefix else text
 
+    def rst_table(self) -> RstTable:
+        param = self.param
+        table = RstTable(param.title or param._default_title, param.description)
+        for choice in param.choices.values():
+            usage = choice.format_usage()
+            table.add_row(f'``{usage}``', choice.help)
+        return table
+
 
 class PassThruHelpFormatter(ParamHelpFormatter, param_cls=PassThru):
     def format_basic_usage(self) -> str:
@@ -153,16 +169,16 @@ class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa
         choices = ','.join(mem.formatter.format_usage(include_meta, full, delim) for mem in self.param.members)
         return f'{{{choices}}}'
 
-    def format_description(self, group_type: Bool = True) -> str:
+    def format_description(self, rst: Bool = False) -> str:
         group = self.param
         if not group.description and not group._name:
-            if group_type and (group.mutually_exclusive or group.mutually_dependent):
+            if ctx.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
                 return 'Mutually {} options'.format('exclusive' if group.mutually_exclusive else 'dependent')
             else:
                 return 'Optional arguments'
         else:
             description = group.description or f'{group.name} options'
-            if group_type and (group.mutually_exclusive or group.mutually_dependent):
+            if ctx.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
                 description += ' (mutually {})'.format('exclusive' if group.mutually_exclusive else 'dependent')
             return description
 
@@ -175,22 +191,18 @@ class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa
         else:
             return '\u2502 '  # BOX DRAWINGS LIGHT VERTICAL
 
-    def format_help(
-        self, width: int = 30, group_type: Bool = True, clean: Bool = True, prefix: str = '', tw_offset: int = 0
-    ) -> str:
+    def format_help(self, width: int = 30, clean: Bool = True, prefix: str = '', tw_offset: int = 0) -> str:
         """
         Prepare the help text for this group.
 
         :param width: The width of the option/action/command column.
-        :param group_type: Whether the group type should be included in the description if this is a mutually
-          exclusive / dependent group
         :param clean: If this group only contains other groups or Action or SubCommand parameters, then omit the
           description.
         :param prefix: Prefix to add to every line (primarily intended for use with nested groups)
         :param tw_offset: Terminal width offset for text width calculations
         :return: The formatted help text.
         """
-        description = self.format_description(group_type)
+        description = self.format_description()
         parts = [f'{description}:']
 
         if ctx.show_group_tree:
@@ -219,3 +231,18 @@ class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa
 
         text = '\n'.join(parts)
         return indent(text, prefix) if prefix else text
+
+    def rst_table(self) -> RstTable:
+        table = RstTable(self.format_description())
+        # TODO: non-nested when config.show_group_tree is False; maybe separate options for rst vs help
+        for member in self.param.members:
+            if member.show_in_help:
+                try:
+                    sub_table: RstTable = member.formatter.rst_table()  # noqa
+                except AttributeError:
+                    table.add_row(*member.formatter.rst_row())
+                else:
+                    sub_table.show_title = False
+                    table.add_row(sub_table.title, str(sub_table))
+
+        return table
